@@ -50,5 +50,20 @@ def openWeb(url):
 def main():
     print("i am main func");
 
+# 递归执行委托，exts是白名单，dirs是黑名单
+def traverseDir(filepath, action, exts=['.txt', '.tex'],dirs=['biantaiwenjianjia']):
+    files = os.listdir(filepath)
+    for fi in files:
+        fi_d = os.path.join(filepath, fi)
+        if os.path.isdir(fi_d):
+            dirName =fi;
+            if dirName not in dirs:
+                traverseDir(fi_d, action, exts,dirs)
+        else:
+            fileNameFull = os.path.abspath(fi_d)
+            ext = os.path.splitext(fileNameFull)[1]
+            if ext in exts:
+                action(fileNameFull)
+
 if __name__ == '__main__':
     main();
\ No newline at end of file
